@@ -5,7 +5,7 @@
 """
 from ctypes import (CFUNCTYPE, POINTER, c_void_p, c_int, c_size_t, c_double,
                     c_char_p, c_ubyte, c_bool)
-from wand.cdefs.wandtypes import c_ssize_t, c_magick_char_p
+from wand.cdefs.wandtypes import c_ssize_t
 
 __all__ = ('MagickProgressMonitor', 'load')
 
@@ -203,6 +203,11 @@ def load(lib, IM_VERSION):
     lib.MagickColorizeImage.restype = c_bool
     lib.MagickColorMatrixImage.argtypes = [c_void_p, c_void_p]
     lib.MagickColorMatrixImage.restype = c_bool
+    if IM_VERSION > 0x709:
+        lib.MagickColorThresholdImage.argtypes = [c_void_p, c_void_p, c_void_p]
+        lib.MagickColorThresholdImage.restype = c_bool
+    else:
+        lib.MagickColorThresholdImage = None
     lib.MagickCommentImage.argtypes = [c_void_p, c_char_p]
     lib.MagickCommentImage.restype = c_bool
     lib.MagickCombineImages.argtypes = [c_void_p, c_int]
@@ -402,7 +407,7 @@ def load(lib, IM_VERSION):
     lib.MagickGaussianBlurImage.restype = c_bool
     if is_im_6:
         lib.MagickGaussianBlurImageChannel.argtypes = [
-            c_void_p, c_double, c_double
+            c_void_p, c_int, c_double, c_double
         ]
         lib.MagickGaussianBlurImageChannel.restype = c_bool
     else:
@@ -480,9 +485,9 @@ def load(lib, IM_VERSION):
         lib.MagickGetImageFeatures.argtypes = [c_void_p, c_size_t]
         lib.MagickGetImageFeatures.restype = c_void_p
     lib.MagickGetImageFilename.argtypes = [c_void_p]
-    lib.MagickGetImageFilename.restype = c_magick_char_p
+    lib.MagickGetImageFilename.restype = c_void_p
     lib.MagickGetImageFormat.argtypes = [c_void_p]
-    lib.MagickGetImageFormat.restype = c_magick_char_p
+    lib.MagickGetImageFormat.restype = c_void_p
     lib.MagickGetImageFuzz.argtypes = [c_void_p]
     lib.MagickGetImageFuzz.restype = c_double
     lib.MagickGetImageGamma.argtypes = [c_void_p]
@@ -569,7 +574,7 @@ def load(lib, IM_VERSION):
     lib.MagickGetImageScene.argtypes = [c_void_p]
     lib.MagickGetImageScene.restype = c_size_t
     lib.MagickGetImageSignature.argtypes = [c_void_p]
-    lib.MagickGetImageSignature.restype = c_magick_char_p
+    lib.MagickGetImageSignature.restype = c_void_p
     lib.MagickGetImageTicksPerSecond.argtypes = [c_void_p]
     lib.MagickGetImageTicksPerSecond.restype = c_size_t
     lib.MagickGetImageTotalInkDensity.argtypes = [c_void_p]
@@ -612,7 +617,7 @@ def load(lib, IM_VERSION):
     else:
         lib.MagickHoughLineImage = None
     lib.MagickIdentifyImage.argtypes = [c_void_p]
-    lib.MagickIdentifyImage.restype = c_magick_char_p
+    lib.MagickIdentifyImage.restype = c_void_p
     if is_im_6:
         lib.MagickImplodeImage.argtypes = [c_void_p, c_double]
     else:
@@ -627,6 +632,16 @@ def load(lib, IM_VERSION):
         c_void_p, c_void_p, c_double
     ]
     lib.MagickInverseFourierTransformImage.restype = c_bool
+    if IM_VERSION > 0x709:
+        try:
+            lib.MagickKmeansImage.argtypes = [
+                c_void_p, c_size_t, c_size_t, c_double
+            ]
+            lib.MagickKmeansImage.restype = c_bool
+        except AttributeError:
+            lib.MagickKmeansImage = None
+    else:
+        lib.MagickKmeansImage = None
     if IM_VERSION >= 0x708:
         try:
             lib.MagickKuwaharaImage.argtypes = [c_void_p, c_double, c_double]
@@ -1195,6 +1210,14 @@ def load(lib, IM_VERSION):
             lib.MagickWaveletDenoiseImage = None
     else:
         lib.MagickWaveletDenoiseImage = None
+    if IM_VERSION > 0x709:
+        try:
+            lib.MagickWhiteBalanceImage.argtypes = [c_void_p]
+            lib.MagickWhiteBalanceImage.restype = c_bool
+        except AttributeError:
+            lib.MagickWhiteBalanceImage = None
+    else:
+        lib.MagickWhiteBalanceImage = None
     lib.MagickWhiteThresholdImage.argtypes = [c_void_p, c_void_p]
     lib.MagickWhiteThresholdImage.restype = c_bool
     lib.MagickWriteImage.argtypes = [c_void_p, c_char_p]
